require 'spec_helper'

describe Jibe::HashMapper do
  include_context "hashes"
  include_context "mappings"

  describe "Request" do
    subject do
     Jibe::HashMapper.new(request_key_map, request_value_map).map(request_hash)
    end

    it "maps request attributes" do
      expect(subject).to include({
        jobRequisitionId:   request_hash[:id],
        title:              request_hash[:title],
        description:        request_hash[:description],
        applyType:          request_hash[:apply_type],
        applyUrl:           request_hash[:apply_url],
        employmentTypes:    ['fulltime', 'parttime'],
        experienceLevel:    'entryLevel',
        yearsExperience:    request_hash[:years_experience],
        education:          'highschool',
        compensationType:   request_hash[:compensation_type],
        compensationAmount: request_hash[:compensation_amount],
        companyId:          'EieNKiU3EQtPFB7H'
      })
    end
  end

  describe "Response" do
    subject do
     Jibe::HashMapper.new(response_key_map, response_value_map). map(response_hash)
    end

    it "maps response attributes" do
      expect(subject).to include({
        destination_post_id: response_hash['id'],
        title:               response_hash['title'],
        description:         response_hash['description'],
        apply_type:          response_hash['applyType'],
        apply_url:           response_hash['applyUrl'],
        employment_types:    ['full_time', 'part_time'],
        experience_level:    'entry_level',
        years_experience:    response_hash['yearsExperience'],
        education:           'high_school',
        compensation_type:   response_hash['compensationType'],
        compensation_amount: response_hash['compensationAmount'],
        garage_company_id:   'EieNKiU3EQtPFB7H'
      })
    end
  end
end
